@@ -82,7 +82,7 @@ use XSLoader;
 our $VERSION;
 
 BEGIN {
-    $VERSION = '0.01';
+    $VERSION = '0.01_01';
 
     XSLoader::load( __PACKAGE__, $VERSION );
 }
@@ -107,9 +107,9 @@ Numeric constants that indicate the corresponding WebAssembly type.
 
 =head1 METHODS
 
-=head2 $OBJ = I<CLASS>->new()
+=head2 $WASM3_ENV = I<CLASS>->new()
 
-Instantiates I<CLASS>.
+Instanties I<CLASS>.
 Creates a new wasm3 environment and binds it to the returned object.
 
 =head2 $RUNTIME = I<OBJ>->create_runtime( $STACKSIZE )
